WeakHashSet<E extends Object> class
An unordered hash-table based Set implementation with weak referenced elements. An element in this weak hash set will be automatically removed when it is garbage collected. That is, when there is no other way for the program to access the weak referenced element, it is likely removed from this WeakHashSet anytime.
Note that the element object of type E must be a type that can be
applied into WeakReference target. i.e. E must NOT be numbers, strings,
booleans, records, null, dart:ffi pointers, dart:ffi structs, or
dart:ffi unions.
Besides the weak referenced elements, the attributes of this WeakHashSet is the same to regular HashSet.
- Mixed-in types
-
- SetMixin<
E>
- SetMixin<
- Available extensions
Constructors
- WeakHashSet({bool equals(E, E)?, int hashCode(E)?, bool isValidKey(dynamic)?})
- Create a hash set using the provided equals as equality.
- WeakHashSet.from(Iterable elements)
-
Create a hash set containing all
elements. - WeakHashSet.identity()
-
Creates an unordered identity-based set.
factory
-
WeakHashSet.of(Iterable<
E> elements) -
Create a hash set containing all
elements.
Properties
- first → E
-
The first element.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether this collection has no elements.
no setteroverride
- isNotEmpty → bool
-
Whether this collection has at least one element.
no setteroverride
-
iterator
→ Iterator<
E> -
An iterator that iterates over the elements of this set.
no setteroverride
- last → E
-
The last element.
no setterinherited
- length → int
-
The number of elements in this Iterable.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- single → E
-
Checks that this iterable has only one element, and returns that element.
no setterinherited
-
wait
→ Future<
List< T> > -
Available on Iterable<
Waits for futures in parallel.Future< , provided by the FutureIterable extensionT> >no setter
Methods
-
add(
E value) → bool -
Adds
valueto the set.override -
addAll(
Iterable< E> elements) → void -
Adds all
elementsto this set.inherited -
any(
bool test(E element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
asNameMap(
) → Map< String, T> -
Available on Iterable<
Creates a map from the names of enum values to the values.T> , provided by the EnumByName extension -
byName(
String name) → T -
Available on Iterable<
Finds the enum value in this list with nameT> , provided by the EnumByName extensionname. -
cast<
R> () → Set< R> -
Provides a view of this set as a set of
Rinstances.inherited -
clear(
) → void -
Removes all elements from the set.
override
-
contains(
Object? element) → bool -
Whether
valueis in the set.override -
containsAll(
Iterable< Object?> other) → bool -
Whether this set contains all the elements of
other.inherited -
difference(
Set< Object?> other) → Set<E> -
Creates a new set with the elements of this that are not in
other.inherited -
elementAt(
int index) → E -
Returns the
indexth element.inherited -
every(
bool f(E element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
expand<
T> (Iterable< T> f(E element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
firstWhere(
bool test(E value), {E orElse()?}) → E -
The first element that satisfies the given predicate
test.inherited -
fold<
T> (T initialValue, T combine(T previousValue, E element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
followedBy(
Iterable< E> other) → Iterable<E> -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void f(E element)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
intersection(
Set< Object?> other) → Set<E> -
Creates a new set which is the intersection between this set and
other.inherited -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
lastWhere(
bool test(E value), {E orElse()?}) → E -
The last element that satisfies the given predicate
test.inherited -
lookup(
Object? element) → E? -
If an object equal to
objectis in the set, return it.override -
map<
T> (T f(E element)) → Iterable< T> -
The current elements of this iterable modified by
toElement.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reduce(
E combine(E value, E element)) → E -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
remove(
Object? value) → bool -
Removes
valuefrom the set.override -
removeAll(
Iterable< Object?> elements) → void -
Removes each element of
elementsfrom this set.inherited -
removeWhere(
bool test(E element)) → void -
Removes all elements of this set that satisfy
test.inherited -
retainAll(
Iterable< Object?> elements) → void -
Removes all elements of this set that are not elements in
elements.inherited -
retainWhere(
bool test(E element)) → void -
Removes all elements of this set that fail to satisfy
test.inherited -
singleWhere(
bool test(E value), {E orElse()?}) → E -
The single element that satisfies
test.inherited -
skip(
int n) → Iterable< E> -
Creates an Iterable that provides all but the first
countelements.inherited -
skipWhile(
bool test(E value)) → Iterable< E> -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
take(
int n) → Iterable< E> -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeWhile(
bool test(E value)) → Iterable< E> -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
toList(
{bool growable = true}) → List< E> -
Creates a List containing the elements of this Iterable.
inherited
-
toSet(
) → Set< E> -
Creates a Set with the same elements and behavior as this
Set.override -
toString(
) → String -
A string representation of this object.
inherited
-
union(
Set< E> other) → Set<E> -
Creates a new set which contains all the elements of this set and
other.inherited -
where(
bool f(E element)) → Iterable< E> -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereType<
T> () → Iterable< T> -
Creates a new lazy Iterable with all elements that have type
T.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited