WeakList<E extends Object> class

An ordered List implementation with weak referenced elements. An element in this weak list will be automatically nullified when it is garbage collected. That is, when there is no other way for the program to access the weak referenced element, it is likely nullified from this WeakList anytime. That is, the (List.[]) operator may return null if the element at the specified index is garbage collected.

Note that the element object of type E must be a type that can be applied into WeakReference target. i.e. E must NOT be numbers, strings, booleans, records, null, dart:ffi pointers, dart:ffi structs, or dart:ffi unions.

Besides the weak referenced elements, the attributes of this WeakList is the same to regular List.

Mixed-in types
Available extensions

Constructors

WeakList()
WeakList.empty({bool growable = false})
Create a new empty WeakList.
factory
WeakList.filled(int length, E? fill, {bool growable = false})
Create a WeakList of the given length with fill at each position.
factory
WeakList.from(Iterable elements, {bool growable = true})
Create a WeakList from elements in its iteration order. Note all elements must be type of E or null.
factory
WeakList.generate(int length, E? generator(int index), {bool growable = true})
Generates a list of values. Create a WeakList with length positions and fills it with values created by calling generator for each index in the range 0 .. length - 1 in increasing order.
factory
WeakList.of(Iterable<E?> elements, {bool growable = true})
Create a WeakList from elements in its iteration order.
factory
WeakList.unmodifiable(Iterable elements)
Creates an unmodifiable WeakList containing all elements in its iteration order.
factory

Properties

first ↔ E?
The first element.
getter/setter pairinherited-setteroverride-getter
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
hashCode int
The hash code for this object.
no setterinherited
indexed Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty bool
Whether this collection has no elements.
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
iterator Iterator<E?>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last ↔ E?
The last element.
getter/setter pairinherited-setteroverride-getter
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length int
The number of objects in this list.
getter/setter pairoverride
nonNulls Iterable<E>
no setter
nonNulls Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
nonNullsReversed Iterable<E>
no setter
reversed Iterable<E?>
An Iterable of the objects in this list in reverse order.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single → E?
Checks that this iterable has only one element, and returns that element.
no setteroverride
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
toJS JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or cloning the List.
no setter
toJSProxyOrRef JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or proxying the List.
no setter
wait Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(E? element) → void
Adds value to the end of this list, extending the length by one.
override
addAll(Iterable<E?> iterable) → void
Appends all objects of iterable to the end of this list.
override
any(bool test(E? element)) bool
Checks whether any element of this iterable satisfies test.
override
asMap() Map<int, E?>
An unmodifiable Map view of this list.
override
asNameMap() Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<R>() List<R>
Returns a view of this list as a list of R instances.
inherited
clear() → void
Removes all objects from this list; the length of the list becomes zero.
override
contains(Object? element) bool
Whether the collection contains an element equal to element.
override
elementAt(int index) → E?
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool test(E? element)) bool
Checks whether every element of this iterable satisfies test.
override
expand<T>(Iterable<T> f(E? element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
fillRange(int start, int end, [E? fill]) → void
Overwrites a range of elements with fillValue.
override
firstWhere(bool test(E? element), {E? orElse()?}) → E?
The first element that satisfies the given predicate test.
override
fold<T>(T initialValue, T combine(T previousValue, E? element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
override
followedBy(Iterable<E?> other) Iterable<E?>
Creates the lazy concatenation of this iterable and other.
override
forEach(void action(E? element)) → void
Invokes action on each element of this iterable in iteration order.
override
getNonNullRange(int start, int end) Iterable<E>
getNonNullRangeReversed(int start, int end) Iterable<E>
getRange(int start, int end) Iterable<E?>
Creates an Iterable that iterates over a range of elements.
override
indexOf(Object? element, [int start = 0]) int
The first index of element in this list.
override
indexWhere(bool test(E? element), [int start = 0]) int
The first index in the list that satisfies the provided test.
override
insert(int index, E? element) → void
Inserts element at position index in this list.
override
insertAll(int index, Iterable<E?> iterable) → void
Inserts all objects of iterable at position index in this list.
override
insertNulls(int index, int count) → void
Insert count of nulls into this WeakList at index.
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastIndexOf(Object? element, [int? start]) int
The last index of element in this list.
override
lastIndexWhere(bool test(E? element), [int? start]) int
The last index in the list that satisfies the provided test.
override
lastWhere(bool test(E? element), {E? orElse()?}) → E?
The last element that satisfies the given predicate test.
override
map<T>(T f(E? element)) Iterable<T>
The current elements of this iterable modified by toElement.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(E? combine(E? previousValue, E? element)) → E?
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
override
remove(Object? element) bool
Removes the first occurrence of value from this list.
override
removeAt(int index) → E?
Removes the object at position index from this list.
override
removeLast() → E?
Removes and returns the last object in this list.
override
removeRange(int start, int end) → void
Removes a range of elements from the list.
override
removeWhere(bool test(E? element)) → void
Removes all objects from this list that satisfy test.
override
replaceRange(int start, int end, Iterable<E?> newContents) → void
Replaces a range of elements with the elements of replacements.
override
retainWhere(bool test(E? element)) → void
Removes all objects from this list that fail to satisfy test.
override
setAll(int index, Iterable<E?> iterable) → void
Overwrites elements with the objects of iterable.
override
setRange(int start, int end, Iterable<E?> iterable, [int skipCount = 0]) → void
Writes some elements of iterable into a range of this list.
override
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
inherited
singleWhere(bool test(E? element), {E? orElse()?}) → E?
The single element that satisfies test.
override
skip(int count) Iterable<E?>
Creates an Iterable that provides all but the first count elements.
override
skipWhile(bool test(E? elm)) Iterable<E?>
Creates an Iterable that skips leading elements while test is satisfied.
override
sort([int compare(E? a, E? b)?]) → void
Default comparison would deem null element as largest, i.e. null would be at the end of this List. If you want to change this default behaviour, must provide a new compare function.
override
sublist(int start, [int? end]) WeakList<E>
Returns a new WeakList containing the elements between start and end. Note that sublist of this WeakList is also a WeakList.
override
take(int count) Iterable<E?>
Creates a lazy iterable of the count first elements of this iterable.
override
takeWhile(bool test(E? value)) Iterable<E?>
Creates a lazy iterable of the leading elements satisfying test.
override
toList({bool growable = true}) List<E?>
Creates a List containing the elements of this Iterable.
inherited
toSet() Set<E?>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
A string representation of this object.
override
validElementCount() → void
Returns the count of valid elements only.
where(bool test(E? value)) Iterable<E?>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
override
whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator +(List<E?> other) List<E?>
Returns the concatenation of this list and other.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) → E?
The object at the given index in the list.
override
operator []=(int index, E? value) → void
Sets the value at the given index in the list to value.
override